@@ -1,5 +1,7 @@
 pub mod cli;
+pub mod compute;
+pub mod constants;
 pub mod gh;
 pub mod iam;
+pub mod init;
 pub mod run;
-pub mod init;
\ No newline at end of file
